@@ -78,10 +78,12 @@ class BaseTable:
     def delete_all(self):
         return self.engine.execute(delete(self.table))
 
-    def upsert(self, values):
-        stmt = insert(self.table).values(values)
+    def upsert(self, value):
+        stmt = insert(self.table).values([value])
         primary_keys = [key.name for key in inspect(self.table).primary_key]
         update_dict = {c.name: c for c in stmt.inserted if
-                       not c.primary_key and c.name not in ('gmt_create', 'gmt_modified')}
+                       not c.primary_key and c.name not in ('gmt_create', 'gmt_modified') and c.name in value.keys() and value[c.name] is not None }
+        if len(update_dict) == 0:
+            return
         stmt = stmt.on_duplicate_key_update(update_dict)
         self.engine.execute(stmt)
