@@ -29,12 +29,8 @@ class StrategyTask(BaseTask):
         
         for symbol_info in json.loads(ticker24h.to_json(orient='records')):
             try:
-
                 symbol = symbol_info['symbol']
-                if not symbol.startswith("BTC/"):
-                    continue
-
-                if not symbol.endswith('BUSD'):
+                if symbol not in ("BTCBUSD", "BTC/BUSD"):
                     continue
 
                 time.sleep(1)
@@ -53,7 +49,7 @@ class StrategyTask(BaseTask):
             try:
                 time.sleep(1)
                 symbol = row['symbol']
-                if row['status']==2:
+                if row['status'] != 2:
                     continue
                 price = self.current_price(symbol)
 
