@@ -64,7 +64,7 @@ class Strategy2Task(BaseTask):
                 buy_price = buy_info['price']
                 amount = buy_info['amount']
                 timestamp = buy_info['timestamp']
-                if time.time() * 1000 - timestamp > 10 * 60 * 1000 and abs((buy_price - price) / price) > 0:
+                if time.time() * 1000 - timestamp > 10 * 60 * 1000 and ((price-buy_price ) / price) > 0.0001:
                     logger.info(f"out of time,sell {buy_price} vs {price}")
                     self.sell_market(row['id'], symbol, amount)
                 elif abs((buy_price - price) / price) > 0.0005:
